#
# spec file for package dwarves
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dwarves
Version:        1.11
Release:        lp150.1.1
Summary:        DWARF utilities
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
Url:            http://acmel.wordpress.com/
#Git-Clone:	git://git.kernel.org/pub/scm/devel/pahole/pahole
#Git-Web:	http://git.kernel.org/cgit/devel/pahole/pahole.git
Source:         https://git.kernel.org/pub/scm/devel/pahole/pahole.git/snapshot/pahole-%version.tar.gz
Source2:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  libdw-devel >= 0.142
BuildRequires:  libebl-devel
BuildRequires:  libelf-devel
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Also known by its most prominent tool
Provides:       pahole = %version-%release

%description
dwarves is a set of tools that use the DWARF debugging information
inserted in ELF binaries by compilers such as GCC, used by well known
debuggers such as GDB, and more recent ones such as systemtap.

Utilities in the dwarves suite include pahole, that can be used to
find alignment holes in structs and classes in languages such as C,
C++, but not limited to these.

It also extracts other information such as CPU cacheline alignment,
helping pack those structures to achieve more cache hits.

A diff like tool, codiff can be used to compare the effects changes
in source code generate on the resulting binaries.

Another tool is pfunct, that can be used to find all sorts of
information about functions, inlines, decisions made by the compiler
about inlining, etc.

The documentation about ctracer is not updated to the latest
developments: it now generates systemtap scripts, stay tuned for
improvements in this area!

%package -n libdwarves1
Summary:        DWARF processing libraries of dwarves tools
Group:          System/Libraries
Requires:       libebl-plugins

%description -n libdwarves1
This package contains the libdwarves shared library for the dwarves
toolset, providing processing for DWARF, a debugging data format
for ELF files.

dwarves is a set of tools that use the DWARF debugging information
inserted in ELF binaries by compilers such as GCC, used by well known
debuggers such as GDB, and more recent ones such as systemtap.

%package -n libdwarves-devel
Summary:        DWARF processing library development files
Group:          Development/Libraries/C and C++
Requires:       libdwarves1 = %version-%release

%description -n libdwarves-devel
This package contains the development files for libdwarves, a library
for processing DWARF, a debugging data format for ELF files.

%prep
%setup -qn pahole-%version

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%post   -n libdwarves1 -p /sbin/ldconfig
%postun -n libdwarves1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README NEWS
%_bindir/*
%_mandir/man*/*

%files -n libdwarves1
%defattr(-,root,root)
%_libdir/*.so.1*

%files -n libdwarves-devel
%defattr(-,root,root)
%_libdir/*.so
%_includedir/*
%_datadir/%name

%changelog
* Mon Mar 26 2018 jengelh@inai.de
- dwarves needs elfutils to have the EBL plugins available
  to carry out its work. [boo#1049871]
- Update to new upstream release 1.11
  * dwarf_loader: Do not stop processing after finding
    unsupported tags
  * dwarf_loader: Support DW_FORM_data{4,8} for reading class
    member offsets
  * dwarf_fprintf: Handle DW_TAG_GNU_call_site{_parameter}
  * dwarf_loader: Add support for DW_TAG_restrict_type
  * dwarf_loader: Initial support for DW_TAG_unspecified_type
- Remove dwarves-no-DW_TAG_mutable.patch (already applied)
* Wed Feb  1 2017 mpluskal@suse.com
- Use cmake macros
* Thu Jan 22 2015 dimstar@opensuse.org
- Add dwarves-no-DW_TAG_mutable.patch: Fix build with newer
  libdwarf versions: DW_TAG_mutable_type was a mistake in an early
  DWARFv3 draft and was removed in the final version.
* Wed Oct 15 2014 jengelh@inai.de
- Drop libdwarf dependency; it is not needed for build (libdw
  is used instead)
* Wed Jun  6 2012 jengelh@inai.de
- Update to new upstream release 1.10
  * Initial DWARF4 support
  * Add stubs for some new GNU tags
  * Fix a crash when pahole is called with -R -S
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
- Implement baselibs config
* Thu Aug 11 2011 jengelh@medozas.de
- Update to new upstream release 1.9
  * Add the "scncopy" tool - like object copy but tries not to change
  section content
  * pfunct: Introduce the -P option
  * dwarves fprintf: Add extra GNU tags
- Update group and description with something more detailed
- Remove redundant %%clean section
- Strip duplicate changelog
- Remove redundant manual requires on libraries
- Update URL to acme's new location
* Wed Apr 13 2011 mgorman@suse.de
- Remove %%debug_package directive which is breaking build
* Mon May  3 2010 lchiquitto@novell.com
- update to 1.8 release
* Fri Feb 29 2008 dmueller@suse.de
- update to 1.6 release
* Sat Dec  1 2007 dgollub@suse.de
- initial package of dwarves
